@@ -10,6 +10,11 @@ from suite_py.lib.handler import prompt_utils
 from suite_py.lib.handler.vault_handler import VaultHandler
 
 profiles_mapping = {
+    "common": {
+        "stack_name_pattern": "{service}-platform-cluster-{env}-serviceaccount-iamrole",
+        "logical_id": "ServiceAccountIamRole",
+        "developer_role": "arn:aws:iam::595659439703:role/aws-reserved/sso.amazonaws.com/eu-west-1/AWSReservedSSO_ItalyDeveloperPlatform_cb5de4d001016cc4",
+    },
     "it": {
         "stack_name_pattern": "ecs-roles-{service}-{env}",
         "logical_id": "ECSTaskRole",
@@ -20,6 +25,11 @@ profiles_mapping = {
         "logical_id": "ServiceAccountIamRole",
         "developer_role": "arn:aws:iam::815911007681:role/aws-reserved/sso.amazonaws.com/eu-west-1/AWSReservedSSO_UnitedKingdomDeveloper_f578b0b2b98ea593",
     },
+    "es": {
+        "stack_name_pattern": "{service}-main-{env}-serviceaccount-iamrole",
+        "logical_id": "ServiceAccountIamRole",
+        "developer_role": "arn:aws:iam::199959896441:role/aws-reserved/sso.amazonaws.com/eu-west-1/AWSReservedSSO_SpainDeveloper_acf53aa98cfc0ac4",
+    },
 }
 
 
